@@ -1,7 +1,8 @@
-__version__ = "3.0.0"
+__version__ = "3.1.0"
 __author__ = "Maxime Barbier"
 
 from .json_include import (
     JSONInclude,
-    build_json
+    build_str,
+    build_json,
 )
